import deepmerge from 'deepmerge'
import React from 'react'

import { PhotoCamera as PhotoCameraIcon } from '@mui/icons-material'
import { Box, Button, ButtonProps } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import useStyles from './styles'

interface Props {
  image?: string
  onChangeImage: React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>['onChange']
  label: string
  imageStyle?: React.HTMLAttributes<HTMLDivElement>['style']
  className?: string
  style?: React.CSSProperties
  sx?: ButtonProps['sx']
}

const ImageUpload = (props: Props) => {
  const { sx = {}, image, onChangeImage, label, imageStyle = {} } = props

  const styles = useStyles(useTheme())

  return (
    <Box sx={deepmerge(sx || {}, styles.container)}>
      {/* <Button variant="text" sx={deepmerge(styles.photoBtn, sx || {})} > */}
      <Button variant="text" component="label" sx={styles.photoBtn}>
        {image ? (
          <div style={deepmerge(styles.card, imageStyle)}>
            <img src={'data:image/png;base64,' + image} style={styles.media} />
          </div>
        ) : (
          <PhotoCameraIcon />
        )}
        {label}
        <input
          type="file"
          // value={image}
          accept="image/jpg, image/jpeg, image/png"
          hidden
          onChange={onChangeImage}
        />
      </Button>
    </Box>
  )
}

export default ImageUpload
